==> haskell-yaml-0.11.0.0-44-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yaml
version: 0.11.0.0
id: yaml-0.11.0.0-29nOs7jnFp62ug02GbzTYG
key: yaml-0.11.0.0-29nOs7jnFp62ug02GbzTYG
license: BSD-3-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov
stability: stable
homepage: https://github.com/snoyberg/yaml#readme
synopsis: Support for parsing and rendering YAML documents.
description:
    README and API documentation are available at <https://www.stackage.org/package/yaml>
category: Data
abi: 9fd062210ecdf00e9f7752b16a1d1fca
exposed: True
exposed-modules:
    Data.Yaml Data.Yaml.Aeson Data.Yaml.Builder Data.Yaml.Config
    Data.Yaml.Include Data.Yaml.Internal Data.Yaml.Parser
    Data.Yaml.Pretty Data.Yaml.TH
hidden-modules: Paths_yaml
import-dirs: /usr/lib/ghc-8.6.5/site-local/yaml-0.11.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/yaml-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yaml-0.11.0.0
hs-libraries: HSyaml-0.11.0.0-29nOs7jnFp62ug02GbzTYG
depends:
    aeson-1.4.3.0-F9e2BgjvX59JUef9tsq2ab
    attoparsec-0.13.2.2-L0PhfJn0b3D3Qcx7KDBMXo base-4.12.0.0
    bytestring-0.10.8.2 conduit-1.3.1.1-Fm1W7uNei6OKfQ1DCXNTzR
    containers-0.6.0.1 directory-1.3.3.0 filepath-1.4.2.1
    libyaml-0.1.1.0-55uBdXNPHOk2kYDpgJeZX5 mtl-2.2.2
    resourcet-1.2.2-njuTV0kmRGB4xSgU2BFrl
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b template-haskell-2.14.0.0
    text-1.2.3.1 transformers-0.5.6.2
    unordered-containers-0.2.10.0-KN3bhnJnJVDChkuCyIQcSr
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-yaml/html/yaml.haddock
haddock-html: /usr/share/doc/haskell-yaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yaml-0.11.0.0-47-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yaml
version: 0.11.0.0
id: yaml-0.11.0.0-5tiUC9jlRkdJe9RddgUA9v
key: yaml-0.11.0.0-5tiUC9jlRkdJe9RddgUA9v
license: BSD-3-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov
stability: stable
homepage: https://github.com/snoyberg/yaml#readme
synopsis: Support for parsing and rendering YAML documents.
description:
    README and API documentation are available at <https://www.stackage.org/package/yaml>
category: Data
abi: 61455d78bb290550b570bbe75aeaad2c
exposed: True
exposed-modules:
    Data.Yaml Data.Yaml.Aeson Data.Yaml.Builder Data.Yaml.Config
    Data.Yaml.Include Data.Yaml.Internal Data.Yaml.Parser
    Data.Yaml.Pretty Data.Yaml.TH
hidden-modules: Paths_yaml
import-dirs: /usr/lib/ghc-8.6.5/site-local/yaml-0.11.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/yaml-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yaml-0.11.0.0
hs-libraries: HSyaml-0.11.0.0-5tiUC9jlRkdJe9RddgUA9v
depends:
    aeson-1.4.3.0-BTVTAPf4Xo575Po56SJ3Aq
    attoparsec-0.13.2.2-IYmscZi60PM1VHlw2sOR1C base-4.12.0.0
    bytestring-0.10.8.2 conduit-1.3.1.1-5tT7brArM8HFpf8jCW5Sg8
    containers-0.6.0.1 directory-1.3.3.0 filepath-1.4.2.1
    libyaml-0.1.1.0-B4LdCDGIDKr2XMgtptXwVE mtl-2.2.2
    resourcet-1.2.2-1jEybJ3raWeJ8zv1YiemYn
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b template-haskell-2.14.0.0
    text-1.2.3.1 transformers-0.5.6.2
    unordered-containers-0.2.10.0-2N7l4ZvxBr3HGayD0s0P1Q
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-yaml/html/yaml.haddock
haddock-html: /usr/share/doc/haskell-yaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
